@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Camera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Camera settings</translation>
+        <source>Select one or more devices</source>
+        <translation>Select one or more devices</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Switch to Window</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Switch to Fullscreen</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Camera</translation>
@@ -92,13 +77,6 @@
         <translation>Dialog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Select one or more devices</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Please install a filemanager.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No filemanager found.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Please install a filemanager.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Donate</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No filemanager found.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Please install a filemanager.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Select one or more devices</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Select one or more devices</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Gray</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Play last recording</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Open folder</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimize when recording starts</translation>
@@ -716,6 +704,50 @@
         <source>Do not record mouse cursor</source>
         <translation>Do not record mouse cursor</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiocodec</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Videopath</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Countdown</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Help</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Invert</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gray</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Black-and-white</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Flip vertical</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Flip horizontal</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Remove window frame</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
