@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Kameraren ezarpenak</translation>
+        <source>Select one or more devices</source>
+        <translation>Hautatu gailu bat edo gehiago</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Aldatu leihora</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Aldatu pantaila osora</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Elkarrizketa</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Hautatu gailu bat edo gehiago</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Instalatu fitxategi-arakatzaile bat.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ez da fitxategi-arakatzailerik aurkitu</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instalatu fitxategi-arakatzaile bat.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Eman dirua</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ez da fitxategi-arakatzailerik aurkitu</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instalatu fitxategi-arakatzaile bat.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Hautatu gailu bat edo gehiago</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Hautatu gailu bat edo gehiago</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Grisa</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+MAIUS+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+MAIUS+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+MAIUS+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Erreproduzitu grabatutako azkena</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Ireki karpeta</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+MAIUS+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizatu grabazioa hastean</translation>
@@ -716,6 +704,50 @@
         <source>Do not record mouse cursor</source>
         <translation>Ez grabatu saguaren erakuslea</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audio-kodeka</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Bideoaren bidea</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Atzera-kontua</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Laguntza</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Alderantzizkatu</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Grisa</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Zuri-beltza</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Irauli bertikalean</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Irauli horizontalean</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Kendu leihoaren markoa</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
