@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Postavke kamere</translation>
+        <source>Select one or more devices</source>
+        <translation>Odaberi jedan ili više uređaja</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Prebaci na prozor</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Prebaci na cijeli zaslon</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Dijalog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Odaberi jedan ili više uređaja</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -118,6 +96,18 @@
         <translation>Molim instalirajte filemanager</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Upravitelj datoteka nije pronađen. 
+ </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Molim instalirajte filemanager</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -192,6 +182,15 @@
         <source>Donate</source>
         <translation>Donirajte</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Upravitelj datoteka nije pronađen. 
+ </translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Molim instalirajte filemanager</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -200,6 +199,13 @@
         <translation>Odaberi jedan ili više uređaja</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Odaberi jedan ili više uređaja</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -488,18 +494,6 @@
         <source>Gray</source>
         <translation>Sivo</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Reproduciraj posljednji zapis</translation>
@@ -508,10 +502,6 @@
         <source>Open folder</source>
         <translation>Otvori mapu</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Minimizirano prilikom pokretanja snimanja</translation>
@@ -719,6 +709,50 @@
         <source>Do not record mouse cursor</source>
         <translation>Ne snimaj kursor miša </translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Audiokodek</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Video-put</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Odbrojavanje </translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Pomoć</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Izokreni</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Sivo</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Crno-bijelo</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Okrenite okomito </translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Okreni vodoravno</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Uklonite okvir prozora</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
