@@ -7,17 +7,10 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraController</name>
+    <name>QvkAudioController_wl</name>
     <message>
-        <source>Camera</source>
-        <translation>Kamera</translation>
-    </message>
-</context>
-<context>
-    <name>QvkCameraSettingsDialog</name>
-    <message>
-        <source>Camera settings</source>
-        <translation>Kamera ayarları</translation>
+        <source>Select one or more devices</source>
+        <translation>Bir veya daha fazla aygıt seç</translation>
     </message>
 </context>
 <context>
@@ -57,14 +50,6 @@
 </context>
 <context>
     <name>QvkCameraWindow</name>
-    <message>
-        <source>Switch to Window</source>
-        <translation>Pencereye Geç</translation>
-    </message>
-    <message>
-        <source>Switch to Fullscreen</source>
-        <translation>Tam Ekrana Geç</translation>
-    </message>
     <message>
         <source>Camera</source>
         <translation>Kamera</translation>
@@ -92,13 +77,6 @@
         <translation>Diyalog</translation>
     </message>
 </context>
-<context>
-    <name>QvkDirectSoundController</name>
-    <message>
-        <source>Select one or more devices</source>
-        <translation>Bir veya daha fazla aygıt seç</translation>
-    </message>
-</context>
 <context>
     <name>QvkHelp</name>
     <message>
@@ -117,6 +95,17 @@
         <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
     </message>
 </context>
+<context>
+    <name>QvkImageFromTabs_wl</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Dosya yöneticisi bulunamadı</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
+    </message>
+</context>
 <context>
     <name>QvkLimitDiskFreeSpace</name>
     <message>
@@ -190,6 +179,14 @@
         <source>Donate</source>
         <translation>Bağış</translation>
     </message>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Dosya yöneticisi bulunamadı</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
+    </message>
 </context>
 <context>
     <name>QvkPulseAudioWatcher</name>
@@ -198,6 +195,13 @@
         <translation>Bir veya daha fazla aygıt seç</translation>
     </message>
 </context>
+<context>
+    <name>QvkPulseAudioWatcher_wl</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>Bir veya daha fazla aygıt seç</translation>
+    </message>
+</context>
 <context>
     <name>QvkRegionChoise</name>
     <message>
@@ -485,18 +489,6 @@
         <source>Gray</source>
         <translation>Gri</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F10</source>
-        <translation>CTRL+SHIFT+F10</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F11</source>
-        <translation>CTRL+SHIFT+F11</translation>
-    </message>
-    <message>
-        <source>CTRL+SHIFT+F12</source>
-        <translation>CTRL+SHIFT+F12</translation>
-    </message>
     <message>
         <source>Play last record</source>
         <translation>Son kaydı oynat</translation>
@@ -505,10 +497,6 @@
         <source>Open folder</source>
         <translation>Klasörü aç</translation>
     </message>
-    <message>
-        <source>CTRL+SHIFT+F8</source>
-        <translation>CTRL+SHIFT+F8</translation>
-    </message>
     <message>
         <source>Minimized when recording starts</source>
         <translation>Kayıt başladığında simge durumuna küçült</translation>
@@ -716,6 +704,50 @@
         <source>Do not record mouse cursor</source>
         <translation>Fare imlecini kayıtta gösterme</translation>
     </message>
+    <message>
+        <source>Audiocodec</source>
+        <translation>Ses çözücü</translation>
+    </message>
+    <message>
+        <source>Videopath</source>
+        <translation>Video yolu</translation>
+    </message>
+    <message>
+        <source>Countdown</source>
+        <translation>Geri sayım</translation>
+    </message>
+    <message>
+        <source>Help</source>
+        <translation>Yardım</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>Ters çevir</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>Gri</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>Siyah-ve-beyaz</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>Dikey çevir</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>Yatay çevir</translation>
+    </message>
+    <message>
+        <source>Remove window frame</source>
+        <translation>Pencere çerçevesini kaldır</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
